from flask import Flask, json, request 
import os
import csv
from shutil import copyfile

print("ReMAP SDK Testing Environment")

DATA_DIR='/app/'

if not os.path.exists(DATA_DIR):
    os.makedirs(DATA_DIR)

copyfile("./data/dataset.csv", "/app/dataset.csv")
copyfile("./data/metadata.json", "/app/metadata.json")
copyfile("./data/sdk_config.json", "/app/sdk_config.json")
copyfile("./data/secret", "/app/secret")

print("configuration loaded")
#-------------------------------------

api = Flask(__name__)

@api.route('/mock/getToken', methods=['POST'])
def getToken():
  req_data = {"access_token":"eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJpc3MiOiJSZU1BUCBNb2NrIEF1dGggU2VydmVyIiwiaWF0IjoxNTk3MTQ0MjkzLCJleHAiOjE2Mjg2ODAyOTMsImF1ZCI6IlRlc3RpbmdfU0RLIiwic3ViIjoidGVzdGluZ19zZGtAcmVtYXAuZXUiLCJHaXZlbk5hbWUiOiJBbGV4IiwiU3VybmFtZSI6IkdhcmNpYSIsIkVtYWlsIjoiYWxlamFuZHJvLmdhcmNpYUBhdG9zLm5ldCIsIlJvbGUiOlsiU29mdHdhcmUgZW5naW5lZXIiLCJQcm9qZWN0IEFkbWluaXN0cmF0b3IiLCJSZXNlYXJjaGVyIl19.sJBKiT1gOkaXKliiWXFF2jKH_aqGf_AHS27wZwkcsoM"}
  return req_data

@api.route('/mock/output', methods=['POST'])
def post_output():
  print("SDK Output received")

  req_data = request.get_json()
  print(req_data)
  return json.dumps(req_data)

if __name__ == '__main__':
    print("Mock ReMAP server for SDK Testing")
    api.run()


#!/usr/bin/python

#Remap SDK module
from remapSDK import remapSDK
#from remapSDK import Sdk


print('##################################### ReMAP WP5 Model PoC #####################################')

remapSdk=remapSDK.Sdk()

start=remapSdk.getStartTime()
print(start)

end_date=remapSdk.getEndTime()
print(end_date)

tailno=remapSdk.getTailNumber()
print(tailno)

partNo=remapSdk.getParamPartNumber("param1")
print(partNo)

metadata=remapSdk.getMetadata()
print(metadata)

replacements=remapSdk.getReplacements()
print(replacements)

jsonoutput={"rulUnit":"test_rul_unit", "rulValue":5, "probabilityOfFailure":44, "confidenceInterval":55}
output=remapSdk.sendOutput( jsonoutput)
print(output)




import csv
import json
from datetime import datetime
import requests

class Sdk:
    '''ReMAP SDK for RUL Algorithms'''

    DIR_BASE = '/app/'
    DATASET_FILE = 'dataset.csv'
    METADATA_FILE = 'metadata.json'
    CONFIG_FILE='sdk_config.json'
    METADATA='metadata'

    config=None
    start_date = None
    end_date = None
    tailNumber = None
    metadata = None
   
    def __init__(self): 
        '''SDK constructor'''
        with open(self.DIR_BASE+self.CONFIG_FILE) as File:
            self.config = json.load(File)            

    def getStartTime(self):
        '''get the start time of metadata'''
        if self.start_date is None:
            with open(self.DIR_BASE+self.METADATA_FILE) as file:
                self.metadata = json.load(file)
            self.start_date = self.metadata['startTime']
        else:
            pass
        return self.start_date

    def getEndTime(self):
        '''get the end time of metadata'''
        if self.end_date is None:
            with open(self.DIR_BASE+self.METADATA_FILE) as file:
                self.metadata = json.load(file)
            self.end_date = self.metadata['endTime']
        else:
            pass
        return self.end_date

    def getTailNumber(self):
        if self.tailNumber is None:
            if self.metadata is None:
                with open(self.DIR_BASE+self.METADATA_FILE) as file:
                    self.metadata = json.load(file)
            self.tailNumber = self.metadata['tailNumber']
        else:
            pass
        return self.tailNumber

    def getMetadata(self):
        with open(self.DIR_BASE+self.METADATA_FILE) as file:
            self.metadata = json.load(file)
        return self.metadata['metadata']

    def getReplacements (self):
        if self.metadata is None:
            with open(self.DIR_BASE+self.METADATA_FILE) as file:
                self.metadata = json.load(file)
        return self.metadata['replacements']

    def getDataset (self):
        return self.DIR_BASE+self.DATASET_FILE
    # return the component PartNo of the parameter passed as param
    
    def getParamPartNumber(self, param):
        PartNo="P/N Not Found"
        if self.metadata is None:
            with open(self.DIR_BASE+self.METADATA_FILE) as file:
                self.metadata = json.load(file)
        self.metadata=self.metadata[self.METADATA]
        for x in self.metadata:
            if x.__contains__('parameter'):
                    parameter =x['parameter']
                    if parameter is not None:
                        name=parameter['name']
                        if name == param:
                            component=parameter['component']
                            PartNo=component['partNo']
        return PartNo

    def sendOutput(self, jsonoutput):
        secret=self.__getClientSecret()
        payload = {
            "serial": self.config['serial'] ,
            "dataset": self.config['dataset'] ,
            "model":self.config['model'],
            "status":"FINISHED",
            "probabilityOfFailure": jsonoutput['probabilityOfFailure'],
            "RULUnit": jsonoutput['rulUnit'],
            "RULValue": jsonoutput['rulValue'],
            "ConfidenceInterval": jsonoutput['confidenceInterval'],
            "runnerId":self.config['runnerId']
            }        
        token=self.__getKCToken(secret)
        json_dump = json.dumps(payload)
        headers={"Content-Type":"application/json","Authorization":"Bearer "+token}
        r=requests.post(self.config['OUTPUT_URL'],headers=headers,data=json_dump)
        return (r.text)

    def __getKCToken(self,secret):
       
        url = self.config['KC_TOKEN_URL']
        payload = {
            "client_id": self.config['CLIENT_ID'] ,
            "grant_type": "client_credentials" ,
            "client_secret":secret}
        r=requests.post(url,data=payload)
        res=json.loads(r.text)   
        return (res['access_token'])
            
    def __getClientSecret(self):
       
        secret="Secret Not Found" 
        with open(self.DIR_BASE+'secret') as file:
            secret=file.read() 
        return secret


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="remapSDK",
    version="0.1.9",
    author="ATOS Mobility Unit",
    author_email="alejandro.garcia@atos.net",
    description="ReMAP SDK for RUL Models",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://h2020-remap.eu/",
    #packages=setuptools.find_packages(),
    install_requires=[
          'requests','flask'
      ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8.5',
    packages=['remapSDK','remapSDK.demo'],
    package_dir={'remapSDK': 'remapSDK'},
    package_data={'remapSDK': ['demo/data/*csv','demo/data/*json','demo/data/secret']},
)